@@ -161,6 +161,9 @@ INVALIDPARAMETER_CDNHOSTINVALIDPARAM = 'InvalidParameter.CdnHostInvalidParam'
 # 域名状态不合法。
 INVALIDPARAMETER_CDNHOSTINVALIDSTATUS = 'InvalidParameter.CdnHostInvalidStatus'
 
+# 该域名为COS访问域名，无法接入，如需启动加速服务，请前往COS控制台启用默认 CDN 加速域。
+INVALIDPARAMETER_CDNHOSTISCOSDEFAULTACCESS = 'InvalidParameter.CdnHostIsCosDefaultAccess'
+
 # 域名太长。
 INVALIDPARAMETER_CDNHOSTTOOLONGHOST = 'InvalidParameter.CdnHostTooLongHost'
 
